@@ -15,15 +15,6 @@
 #define		P_ETRN		7
 #define		P_ODMR		8
 
-/* 
- * We need to distinguish between mailbox and mailbag protocols.
- * Under a mailbox protocol wwe're pulling mail for a speecific user
- * and the transaction must be authenticated.  Under a mailbag protocol
- * we're fetching mail for an entire domain; the client and server
- * authenticate to each other but no per-user authentication is needed.
- */ 
-#define MAILBOX_PROTOCOL(ctl)	((ctl)->server.protocol < P_ETRN)
-
 #if INET6_ENABLE
 #define		SMTP_PORT	"smtp"
 #define		KPOP_PORT	"kpop"
@@ -37,6 +28,13 @@
 #define		SPOP3_PORT	995
 #endif
 
+/* 
+ * We need to distinguish between mailbox and mailbag protocols.
+ * Under a mailbox protocol wwe're pulling mail for a speecific user.
+ * Under a mailbag protocol we're fetching mail for an entire domain.
+ */
+#define MAILBOX_PROTOCOL(ctl)	((ctl)->server.protocol < P_ETRN)
+
 /* authentication types */
 #define		A_ANY		0	/* use the first method that works */
 #define		A_PASSWORD	1	/* password authentication */
@@ -49,7 +47,7 @@
 #define		A_SSH		8	/* authentication at session level */
 
 /* some protocols (KERBEROS, GSSAPI, SSH) don't require a password */
-#define NO_PASSWORD(ctl)	((ctl)->server.authenticate > A_OTP || !MAILBOX_PROTOCOL(ctl))
+#define NO_PASSWORD(ctl)	((ctl)->server.authenticate > A_OTP || (ctl)->server.protocol == P_ETRN)
 
 /*
  * Definitions for buffer sizes.  We get little help on setting maxima
@@ -92,6 +90,7 @@
 #define		PS_DNS		11	/* fatal DNS error */
 #define		PS_BSMTP	12	/* output batch could not be opened */
 #define		PS_MAXFETCH	13	/* poll ended by fetch limit */
+#define		PS_SERVBUSY	14	/* server is busy */
 /* leave space for more codes */
 #define		PS_UNDEFINED	23	/* something I hadn't thought of */
 #define		PS_TRANSIENT	24	/* transient failure (internal use) */
@@ -172,8 +171,6 @@ struct method		/* describe methods for protocol state machine */
     flag delimited;		/* if true, accept "." message delimiter */
     int (*parse_response)(int, char *);
 				/* response_parsing function */
-    int (*password_canonify)(char *, char *, int);
-				/* canonicalize password */
     int (*getauth)(int, struct query *, char *);
 				/* authorization fetcher */
     int (*getrange)(int, struct query *, const char *, int *, int *, int *);
@@ -289,6 +286,7 @@ struct query
     flag use_ssl;		/* use SSL encrypted session */
     char *sslkey;		/* optional SSL private key file */
     char *sslcert;		/* optional SSL certificate file */
+	char *sslproto;		/* force usage of protocol (ssl2|ssl3|tls1) - defaults to ssl23 */
     char *properties;		/* passthrough properties for extensions */
 
     /* internal use -- per-poll state */
@@ -296,6 +294,8 @@ struct query
     const char *destaddr;	/* destination host for this query */
     int errcount;		/* count transient errors in last pass */
     int authfailcount;		/* count of authorization failures */
+	int wehaveauthed;   /* We have managed to logon at least once! */
+	int wehavesentauthnote;   /* We have sent an authorization failure note */
     int wedged;			/* wedged by auth failures or timeouts? */
     char *smtphost;		/* actual SMTP host we connected to */
     int smtp_socket;		/* socket descriptor for SMTP connection */
@@ -377,6 +377,7 @@ extern flag configdump;		/* dump control blocks as Python dictionary */
 extern const char *fetchmailhost;
 				/* either "localhost" or an FQDN */
 extern int suppress_tags;	/* suppress tags in tagged protocols? */
+extern char shroud[PASSWORDLEN];	/* string to shroud in debug output */
 #ifdef SDPS_ENABLE
 extern char *sdps_envfrom;
 extern char *sdps_envto;
@@ -410,6 +411,11 @@ int gen_recv();
 int gen_transact ();
 #endif
 
+/* lock.c: concurrency locking */
+void lock_setup(void), lock_assert(void);
+void lock_or_die(void), lock_release(void);
+int lock_state(void);
+
 /* use these to track what was happening when the nonresponse timer fired */
 #define GENERAL_WAIT	0	/* unknown wait type */
 #define OPEN_WAIT	1	/* waiting from mailserver open */
