@@ -76,10 +76,11 @@
 #define LA_SSL		50
 #define LA_SSLKEY	51
 #define LA_SSLCERT	52
+#define LA_SSLPROTO 53
 #endif
 
-#define LA_SHOWDOTS	53
-#define LA_PRINCIPAL	54
+#define LA_SHOWDOTS	54
+#define LA_PRINCIPAL	55
 
 /* options still left: CDgGhHjJoORwWxXYz */
 static const char *shortoptions = 
@@ -146,6 +147,7 @@ static const struct option longoptions[] = {
   {"ssl",       no_argument,       (int *) 0, LA_SSL        },
   {"sslkey",    required_argument, (int *) 0, LA_SSLKEY     },
   {"sslcert",   required_argument, (int *) 0, LA_SSLCERT    },
+  {"sslproto",   required_argument, (int *) 0, LA_SSLPROTO    },
 #endif
 
   {"principal", required_argument, (int *) 0, LA_PRINCIPAL },
@@ -360,6 +362,8 @@ struct query *ctl;	/* option record to be initialized */
 		ctl->server.protocol = P_IMAP;
 	    else if (strcasecmp(optarg,"etrn") == 0)
 		ctl->server.protocol = P_ETRN;
+	    else if (strcasecmp(optarg,"odmr") == 0)
+		ctl->server.protocol = P_ODMR;
 	    else {
 		fprintf(stderr,_("Invalid protocol `%s' specified.\n"), optarg);
 		errflag++;
@@ -392,6 +396,18 @@ struct query *ctl;	/* option record to be initialized */
 		ctl->server.authenticate = A_KERBEROS_V4;
 	    else if (strcmp(optarg, "ssh") == 0)
 		ctl->server.authenticate = A_SSH;
+	    else if (strcmp(optarg, "otp") == 0)
+		ctl->server.authenticate = A_OTP;
+	    else if (strcmp(optarg, "ntlm") == 0)
+		ctl->server.authenticate = A_NTLM;
+	    else if (strcmp(optarg, "cram") == 0)
+		ctl->server.authenticate = A_CRAM_MD5;
+	    else if (strcmp(optarg, "cram-md5") == 0)
+		ctl->server.authenticate = A_CRAM_MD5;
+	    else if (strcmp(optarg, "gssapi") == 0)
+		ctl->server.authenticate = A_GSSAPI;
+	    else if (strcmp(optarg, "any") == 0)
+		ctl->server.authenticate = A_ANY;
 	    else {
 		fprintf(stderr,_("Invalid authentication `%s' specified.\n"), optarg);
 		errflag++;
@@ -548,6 +564,10 @@ struct query *ctl;	/* option record to be initialized */
 	case LA_SSLCERT:
 	    ctl->sslcert = xstrdup(optarg);
 	    break;
+
+	case LA_SSLPROTO:
+	    ctl->sslproto = xstrdup(optarg);
+	    break;
 #endif
 
 	case LA_PRINCIPAL:
@@ -613,6 +633,7 @@ struct query *ctl;	/* option record to be initialized */
 	P(_("      --ssl         enable ssl encrypted session\n"));
 	P(_("      --sslkey      ssl private key file\n"));
 	P(_("      --sslcert     ssl client certificate\n"));
+	P(_("      --sslproto    force ssl protocol (ssl2/ssl3/tls1)\n"));
 #endif
 	P(_("      --plugin      specify external command to open connection\n"));
 	P(_("      --plugout     specify external command to open smtp connection\n"));
